Jupyter Notebooks — linkml documentation

# Jupyter Notebooks

Currently there are a small number of example notebooks that demonstrate programmatic usage

## LinkML Notebooks

These notebooks illustrate different aspects of the linkml ecosystem:

github.com/linkml/linkml/tree/main/notebooks

## linkml-runtime Notebooks

Currently the only notebooks here demonstrate schema views. More will be added later.

github.com/linkml/linkml-runtime/tree/main/notebooks